==> nuke-number-picker-2.0.2.tgz: package/src/index.jsx <==
'use strict';

/** @jsx createElement */
import { Component, createElement, PropTypes } from 'rax';
import View from 'nuke-view';
import Touchable from 'nuke-touchable';
import { connectStyle } from 'nuke-theme-provider';
import Icon from 'nuke-icon';
import Input from 'nuke-input';
import stylesProvider from './styles';

const noop = () => {};
class NumberPicker extends Component {
  constructor(props) {
    super(props);

    let value;
    if ('value' in props) {
      value = props.value;
    } else {
      value = props.defaultValue;
    }
    value = this.getValidValue(value);
    this.state = {
      value,
      error: false,
      focused: false,
      displayValue: value,
    };
    ['onAdd', 'onReduce', 'onChange', 'onFocus', 'onBlur'].forEach((m) => {
      this[m] = this[m].bind(this);
    });
  }
  componentWillReceiveProps(nextProps) {
    // todo: dynamic min & max
    if ('value' in nextProps) {
      const value = this.getValidValue(nextProps.value);
      this.setState({
        value,
        displayValue: value,
      });
    }
  }
  onAdd() {
    this.setValue(this.state.value + this.props.step);
  }
  onReduce() {
    this.setValue(this.state.value - this.props.step);
  }
  onChange(val, e) {
    if (this.props.editable) {
      this.setState({
        displayValue: val.trim(),
      });
    }
    this.setValue(+val);
  }
  onFocus() {
    this.setState({ focused: true });
  }

  onBlur(e) {
    // debugger;
    const val = this.refs.numberpicker.wrappedInstance.getValue();

    this.setValue(+val);

    // const val = e.value || e.target.value;

    this.setState({ focused: false });
  }
  setValue(displayValue) {
    let flag;
    let value;
    let error = false;
    const { disabled, autoCorrect, onChange } = this.props;

    if (disabled) {
      return;
    }

    value = this.state.value;
    const validValue = this.getValidValue(displayValue);

    if (autoCorrect) {
      value = displayValue = validValue;
    } else {
      error = validValue !== displayValue;
      if (!error) {
        value = validValue;
      }
    }

    if (
      value !== this.state.value ||
      ((flag = true) && value !== this.state.displayValue)
    ) {
      if (!('value' in this.props)) {
        this.setState({
          value,
          displayValue,
        });
      } else if (!error) {
        this.setState({
          displayValue: this.state.value,
        });
      }

      this.setState({
        error,
      });

      if (!flag) {
        onChange(value);
      }
    }
  }

  getValue() {
    return this.state.value;
  }
  getValidValue(value) {
    const { min, max } = this.props;

    value = value === '' ? this.state.value : Number(value);
    value = isNaN(value)
      ? this.state.value
      : value < min ? min : value > max ? max : value;

    return value;
  }
  render() {
    const { value, displayValue, focused, error } = this.state;
    const styles = this.props.themeStyle;
    const inputWrapStyle = Object.assign(
      {},
      styles['input-wrap'],
      error ? styles['error-input-wrap'] : {}
    );
    const {
      min,
      max,
      step,
      disabled,
      editable,
      autoFocus,
      style = {},
    } = this.props;
    const inputAttrs = {};
    if (disabled || !editable) {
      inputAttrs.disabled = true;
    }
    const inputStyle = Object.assign(
      {},
      styles.input,
      disabled || inputAttrs.disabled ? styles['input-disabled'] : null,
      error ? styles['error-input'] : {}
    );

    const reduceDisabled = disabled || value <= min || value - step < min;
    const addDisabled = disabled || value >= max || value + step > max;
    return (
      <View style={[styles['number-picker'], style]}>
        <Touchable
          style={[
            styles.reduce,
            reduceDisabled ? styles['disabled-button'] : {},
          ]}
          onPress={this.onReduce}
        >
          <Icon
            style={[styles.icon, reduceDisabled ? styles['icon-disabled'] : {}]}
            name="minus"
          />
        </Touchable>

        <Input
          inputStyle={inputStyle}
          type="number"
          fixedFont
          ref="numberpicker"
          style={inputWrapStyle}
          materialDesign={false}
          min={min}
          max={max}
          step={step}
          autoFocus={autoFocus}
          {...inputAttrs}
          value={focused || error ? displayValue : value}
          onFocus={this.onFocus}
          onBlur={this.onBlur}
          onChange={this.onChange}
        />
        <Touchable
          style={[styles.add, addDisabled ? styles['disabled-button'] : {}]}
          onPress={this.onAdd}
        >
          <Icon
            style={[styles.icon, addDisabled ? styles['icon-disabled'] : {}]}
            name="add"
          />
        </Touchable>
      </View>
    );
  }
}

NumberPicker.defaultProps = {
  min: 0,
  max: 100,
  step: 1,
  defaultValue: 0,
  editable: true,
  disabled: false,
  autoFocus: false,
  autoCorrect: false,
  onChange: noop,
  style: {},
  themeStyle: {},
};

NumberPicker.propTypes = {
  min: PropTypes.number,
  max: PropTypes.number,
  step: PropTypes.number,
  value: PropTypes.number,
  editable: PropTypes.bool,
  disabled: PropTypes.bool,
  autoFocus: PropTypes.bool,
  autoCorrect: PropTypes.bool,
  defaultValue: PropTypes.number,
  onChange: PropTypes.func,
  style: PropTypes.any,
  themeStyle: PropTypes.any,
};
NumberPicker.displayName = 'NumberPicker';

const StyledNumberPicker = connectStyle(stylesProvider, { withRef: true })(
  NumberPicker
);

export default StyledNumberPicker;

==> nuke-number-picker-2.0.7.tgz: package/src/index.jsx <==
'use strict';

/** @jsx createElement */
import { Component, createElement, PropTypes } from 'rax';
import View from 'nuke-view';
import Touchable from 'nuke-touchable';
import { connectStyle } from 'nuke-theme-provider';
import Icon from 'nuke-icon';
import Input from 'nuke-base-input';
import stylesProvider from './styles';

const noop = () => { };


class NumberPicker extends Component {
  constructor(props) {
    super(props);

    let value;
    if ('value' in props) {
      value = props.value;
    } else {
      value = props.defaultValue;
    }
    value = this.getValidValue(value);
    this.state = {
      value,
      error: false,
      focused: false,
      displayValue: value,
    };
    ['onAdd', 'onReduce', 'onChange', 'onFocus', 'onBlur'].forEach((m) => {
      this[m] = this[m].bind(this);
    });
  }
  componentWillReceiveProps(nextProps) {
    // todo: dynamic min & max
    if ('value' in nextProps) {
      const value = this.getValidValue(nextProps.value);
      this.setState({
        value,
        displayValue: value,
      });
    }
  }
  onAdd() {
    this.setValue(this.state.value + this.props.step);
  }
  onReduce() {
    this.setValue(this.state.value - this.props.step);
  }
  onChange(val, e) {
    if (this.props.editable) {
      this.setState({
        displayValue: val.trim(),
      });
    }
    this.setValue(+val);
  }
  onFocus() {
    this.setState({ focused: true });
  }

  onBlur(e) {
    // debugger;
    const val = this.refs.numberpicker.getValue();

    this.setValue(+val);

    // const val = e.value || e.target.value;

    this.setState({ focused: false });
  }
  setValue(displayValue) {
    let flag;
    let value;
    let error = false;
    const { disabled, autoCorrect, onChange } = this.props;

    if (disabled) {
      return;
    }

    value = this.state.value;
    const validValue = this.getValidValue(displayValue);

    if (autoCorrect) {
      value = displayValue = validValue;
    } else {
      error = validValue !== displayValue;
      if (!error) {
        value = validValue;
      }
    }

    if (
      value !== this.state.value ||
      ((flag = true) && value !== this.state.displayValue)
    ) {
      if (!('value' in this.props)) {
        this.setState({
          value,
          displayValue,
        });
      } else if (!error) {
        this.setState({
          displayValue: this.state.value,
        });
      }

      this.setState({
        error,
      });

      if (!flag) {
        onChange(value);
      }
    }
  }

  getValue() {
    return this.state.value;
  }
  getValidValue(value) {
    const { min, max } = this.props;

    value = value === '' ? this.state.value : Number(value);
    value = isNaN(value)
      ? this.state.value
      : value < min ? min : value > max ? max : value;

    return value;
  }
  render() {
    const { value, displayValue, focused, error } = this.state;
    const styles = this.props.themeStyle;
    const inputWrapStyle = Object.assign(
      {},
      styles['input-wrap'],
      error ? styles['error-input-wrap'] : {}
    );
    const {
      min,
      max,
      step,
      disabled,
      editable,
      autoFocus,
      style = {},
    } = this.props;
    const inputAttrs = {};
    if (disabled || !editable) {
      inputAttrs.disabled = true;
    }
    const inputStyle = Object.assign(
      {},
      styles.input,
      disabled || inputAttrs.disabled ? styles['input-disabled'] : null,
      error ? styles['error-input'] : {}
    );

    const reduceDisabled = disabled || value <= min || value - step < min;
    const addDisabled = disabled || value >= max || value + step > max;
    return (
      <View style={[styles['number-picker'], style]}>
        <Touchable
          style={[
            styles.reduce,
            reduceDisabled ? styles['disabled-button'] : {},
          ]}
          onPress={this.onReduce}
        >
          <Icon
            style={[styles.icon, reduceDisabled ? styles['icon-disabled'] : {}]}
            name="minus"
          />
        </Touchable>

        <Input
          inputStyle={inputStyle}
          type="number"
          fixedFont
          ref="numberpicker"
          style={inputWrapStyle}
          materialDesign={false}
          min={min}
          max={max}
          step={step}
          autoFocus={autoFocus}
          {...inputAttrs}
          value={focused || error ? displayValue : value}
          onFocus={this.onFocus}
          onBlur={this.onBlur}
          onChange={this.onChange}
        />
        <Touchable
          style={[styles.add, addDisabled ? styles['disabled-button'] : {}]}
          onPress={this.onAdd}
        >
          <Icon
            style={[styles.icon, addDisabled ? styles['icon-disabled'] : {}]}
            name="add"
          />
        </Touchable>
      </View>
    );
  }
}

NumberPicker.defaultProps = {
  min: 0,
  max: 100,
  step: 1,
  defaultValue: 0,
  editable: true,
  disabled: false,
  autoFocus: false,
  autoCorrect: false,
  onChange: noop,
  style: {},
  themeStyle: {},
};

NumberPicker.propTypes = {
  min: PropTypes.number,
  max: PropTypes.number,
  step: PropTypes.number,
  value: PropTypes.number,
  editable: PropTypes.bool,
  disabled: PropTypes.bool,
  autoFocus: PropTypes.bool,
  autoCorrect: PropTypes.bool,
  defaultValue: PropTypes.number,
  onChange: PropTypes.func,
  style: PropTypes.any,
  themeStyle: PropTypes.any,
};
NumberPicker.displayName = 'NumberPicker';

const StyledNumberPicker = connectStyle(stylesProvider, { withRef: true })(
  NumberPicker
);

export default StyledNumberPicker;
